# flake8: noqa

# import apis into api package
from dofusdude.api.almanax_api import AlmanaxApi
from dofusdude.api.consumables_api import ConsumablesApi
from dofusdude.api.cosmetics_api import CosmeticsApi
from dofusdude.api.equipment_api import EquipmentApi
from dofusdude.api.game_api import GameApi
from dofusdude.api.meta_api import MetaApi
from dofusdude.api.mounts_api import MountsApi
from dofusdude.api.quest_items_api import QuestItemsApi
from dofusdude.api.resources_api import ResourcesApi
from dofusdude.api.sets_api import SetsApi
from dofusdude.api.webhooks_api import WebhooksApi

